import { AutoMap } from '@automapper/classes';
import {
  IsOptional,
  IsString,
  IsBoolean,
  IsDate,
  IsInt,
  ValidateIf,
  IsArray,
} from 'class-validator';
import { Frequency } from '../entities/frequency.enum';
import { Address } from '../entities/address';
import { Transform, Type } from 'class-transformer';

export class CreateAdRequest {
  @IsString()
  @IsOptional()
  @AutoMap()
  uuid?: string;

  @IsString()
  @AutoMap()
  userUuid: string;

  @ValidateIf((ad) => (ad.passenger ? false : true))
  @IsOptional()
  @IsBoolean()
  @AutoMap()
  driver?: boolean;

  @ValidateIf((ad) => (ad.driver ? false : true))
  @IsOptional()
  @IsBoolean()
  @AutoMap()
  passenger?: boolean;

  @Transform(({ value }) => Frequency[value])
  @AutoMap()
  frequency: Frequency;

  @Type(() => Date)
  @IsDate()
  @AutoMap()
  fromDate: Date;

  @Type(() => Date)
  @IsDate()
  @AutoMap()
  toDate: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  monTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  tueTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  wedTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  thuTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  friTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  satTime?: Date;

  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  sunTime?: Date;

  @IsInt()
  @IsOptional()
  @AutoMap()
  monMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  tueMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  wedMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  thuMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  friMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  satMargin?: number;

  @IsInt()
  @IsOptional()
  @AutoMap()
  sunMargin?: number;

  @ValidateIf((ad) => (ad.passenger ? false : true))
  @IsOptional()
  @IsInt()
  @AutoMap()
  seatsDriver?: number;

  @ValidateIf((ad) => (ad.driver ? false : true))
  @IsOptional()
  @IsInt()
  @AutoMap()
  seatsPassenger?: number;
  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  createdAt?: Date;
  @Type(() => Date)
  @IsDate()
  @IsOptional()
  @AutoMap()
  updatedAt?: Date;

  @IsArray()
  @AutoMap(() => [Address])
  addresses?: Array<Address>;
}
